#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.3.0
visibility:           public
id:                   servant-0.20.3.0-IdmyOV78yaZFChZ6qwJTWn
key:                  servant-0.20.3.0-IdmyOV78yaZFChZ6qwJTWn
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  be93edc791ab92796ff0cb7a51596d51
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.Host
    Servant.API.HttpVersion Servant.API.IsSecure Servant.API.Modifiers
    Servant.API.MultiVerb Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Range
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.ServerSentEvents
    Servant.API.Status Servant.API.Stream Servant.API.Sub
    Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.TypeLevel.List Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.Internal.Response
    Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.3.0-IdmyOV78yaZFChZ6qwJTWn
depends:
    QuickCheck-2.15.0.1-6GEGPgW6PY5CA5PnU98uYH
    aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK
    attoparsec-0.14.4-FIfeiNzOKYm3sEc1QPF51Z base-4.18.2.1
    bifunctors-5.6.2-LE9PMEstwzEJDghPsSArS0 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-HFTLAepm1u61gRs0sAANH
    constraints-0.14.2-7pLXqpyuDrm2qBfA76qVBl containers-0.6.7
    deepseq-1.4.8.1 generics-sop-0.5.1.3-2A8djQkaEZB9fJBOGd7gV
    http-api-data-0.6.1-Lw4gVou82NF35I6uRcXQK0
    http-media-0.8.1.1-Alz4MG10sd7DkM19NIX3Ze
    http-types-0.12.4-Hj8jLUhN6rtnIgKEy5ynr
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1
    network-uri-2.6.4.2-3U0FvLc2coZ6tqjF5PGDly
    singleton-bool-0.1.8-JHJF60P9eTLG8dweMXGGal
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS text-2.0.2
    transformers-0.6.1.0 vault-0.3.1.5-8aun4nqC3v9dehOIlNHGI

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

